@@ -1,5 +1,5 @@
 /*
- *  Copyright 2001-2006 Stephen Colebourne
+ *  Copyright 2001-2006,2008 Stephen Colebourne
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -16,6 +16,8 @@
 package org.joda.time.format;
 
 import java.util.Collection;
+import java.util.HashSet;
+import java.util.Set;
 
 import org.joda.time.DateTimeFieldType;
 import org.joda.time.DateTimeZone;
@@ -69,7 +71,6 @@ public class ISODateTimeFormat {
         hde, // hourOfDay element (HH)
         mhe, // minuteOfHour element (:mm)
         sme, // secondOfMinute element (:ss)
-        lse, // millisOfSecond element (.SSS)
         fse, // fractionOfSecond element (.SSSSSSSSS)
         ze,  // zone offset element
         lte, // literal 'T' element
@@ -203,9 +204,19 @@ public class ISODateTimeFormat {
      * </pre>
      * * indiates that this is not an official ISO format and can be excluded
      * by passing in <code>strictISO</code> as <code>true</code>.
+     * <p>
+     * This method can side effect the input collection of fields.
+     * If the input collection is modifiable, then each field that was added to
+     * the formatter will be removed from the collection, including any duplicates.
+     * If the input collection is unmodifiable then no side effect occurs.
+     * <p>
+     * This side effect processing is useful if you need to know whether all
+     * the fields were converted into the formatter or not. To achieve this,
+     * pass in a modifiable list, and check that it is empty on exit.
      *
      * @param fields  the fields to get a formatter for, not null,
-     *  updated by the method call, which removes those fields built in the formatter
+     *  updated by the method call unless unmodifiable,
+     *  removing those fields built in the formatter
      * @param extended  true to use the extended format (with separators)
      * @param strictISO  true to stick exactly to ISO8601, false to include additional formats
      * @return a suitable formatter
@@ -220,36 +231,45 @@ public class ISODateTimeFormat {
         if (fields == null || fields.size() == 0) {
             throw new IllegalArgumentException("The fields must not be null or empty");
         }
-        int inputSize = fields.size();
+        Set workingFields = new HashSet(fields);
+        int inputSize = workingFields.size();
         boolean reducedPrec = false;
         DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder();
         // date
-        if (fields.contains(DateTimeFieldType.monthOfYear())) {
-            reducedPrec = dateByMonth(bld, fields, extended, strictISO);
-        } else if (fields.contains(DateTimeFieldType.dayOfYear())) {
-            reducedPrec = dateByOrdinal(bld, fields, extended, strictISO);
-        } else if (fields.contains(DateTimeFieldType.weekOfWeekyear())) {
-            reducedPrec = dateByWeek(bld, fields, extended, strictISO);
-        } else if (fields.contains(DateTimeFieldType.dayOfMonth())) {
-            reducedPrec = dateByMonth(bld, fields, extended, strictISO);
-        } else if (fields.contains(DateTimeFieldType.dayOfWeek())) {
-            reducedPrec = dateByWeek(bld, fields, extended, strictISO);
-        } else if (fields.remove(DateTimeFieldType.year())) {
+        if (workingFields.contains(DateTimeFieldType.monthOfYear())) {
+            reducedPrec = dateByMonth(bld, workingFields, extended, strictISO);
+        } else if (workingFields.contains(DateTimeFieldType.dayOfYear())) {
+            reducedPrec = dateByOrdinal(bld, workingFields, extended, strictISO);
+        } else if (workingFields.contains(DateTimeFieldType.weekOfWeekyear())) {
+            reducedPrec = dateByWeek(bld, workingFields, extended, strictISO);
+        } else if (workingFields.contains(DateTimeFieldType.dayOfMonth())) {
+            reducedPrec = dateByMonth(bld, workingFields, extended, strictISO);
+        } else if (workingFields.contains(DateTimeFieldType.dayOfWeek())) {
+            reducedPrec = dateByWeek(bld, workingFields, extended, strictISO);
+        } else if (workingFields.remove(DateTimeFieldType.year())) {
             bld.append(yearElement());
             reducedPrec = true;
-        } else if (fields.remove(DateTimeFieldType.weekyear())) {
+        } else if (workingFields.remove(DateTimeFieldType.weekyear())) {
             bld.append(weekyearElement());
             reducedPrec = true;
         }
-        boolean datePresent = (fields.size() < inputSize);
+        boolean datePresent = (workingFields.size() < inputSize);
         
         // time
-        time(bld, fields, extended, strictISO, reducedPrec, datePresent);
+        time(bld, workingFields, extended, strictISO, reducedPrec, datePresent);
         
         // result
         if (bld.canBuildFormatter() == false) {
             throw new IllegalArgumentException("No valid format for fields: " + fields);
         }
+        
+        // side effect the input collection to indicate the processed fields
+        // handling unmodifiable collections with no side effect
+        try {
+            fields.retainAll(workingFields);
+        } catch (UnsupportedOperationException ex) {
+            // ignore, so we can handle unmodifiable collections
+        }
         return bld.toFormatter();
     }
 
@@ -838,15 +858,15 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a two digit hour of day, two digit minute of
      * hour, two digit second of minute, three digit fraction of second, and
-     * time zone offset (HH:mm:ss.SSSZ).
+     * time zone offset (HH:mm:ss.SSSZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for HH:mm:ss.SSSZ
+     * @return a formatter for HH:mm:ss.SSSZZ
      */
     public static DateTimeFormatter time() {
         if (t == null) {
             t = new DateTimeFormatterBuilder()
-                .append(hourMinuteSecondMillis())
+                .append(hourMinuteSecondFraction())
                 .append(offsetElement())
                 .toFormatter();
         }
@@ -855,10 +875,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter for a two digit hour of day, two digit minute of
-     * hour, two digit second of minute, and time zone offset (HH:mm:ssZ).
+     * hour, two digit second of minute, and time zone offset (HH:mm:ssZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for HH:mm:ssZ
+     * @return a formatter for HH:mm:ssZZ
      */
     public static DateTimeFormatter timeNoMillis() {
         if (tx == null) {
@@ -873,10 +893,10 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a two digit hour of day, two digit minute of
      * hour, two digit second of minute, three digit fraction of second, and
-     * time zone offset prefixed by 'T' ('T'HH:mm:ss.SSSZ).
+     * time zone offset prefixed by 'T' ('T'HH:mm:ss.SSSZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for 'T'HH:mm:ss.SSSZ
+     * @return a formatter for 'T'HH:mm:ss.SSSZZ
      */
     public static DateTimeFormatter tTime() {
         if (tt == null) {
@@ -891,10 +911,10 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a two digit hour of day, two digit minute of
      * hour, two digit second of minute, and time zone offset prefixed
-     * by 'T' ('T'HH:mm:ssZ).
+     * by 'T' ('T'HH:mm:ssZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for 'T'HH:mm:ssZ
+     * @return a formatter for 'T'HH:mm:ssZZ
      */
     public static DateTimeFormatter tTimeNoMillis() {
         if (ttx == null) {
@@ -908,10 +928,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter that combines a full date and time, separated by a 'T'
-     * (yyyy-MM-dd'T'HH:mm:ss.SSSZ).
+     * (yyyy-MM-dd'T'HH:mm:ss.SSSZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for yyyy-MM-dd'T'HH:mm:ss.SSSZ
+     * @return a formatter for yyyy-MM-dd'T'HH:mm:ss.SSSZZ
      */
     public static DateTimeFormatter dateTime() {
         if (dt == null) {
@@ -925,10 +945,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter that combines a full date and time without millis,
-     * separated by a 'T' (yyyy-MM-dd'T'HH:mm:ssZ).
+     * separated by a 'T' (yyyy-MM-dd'T'HH:mm:ssZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for yyyy-MM-dd'T'HH:mm:ssZ
+     * @return a formatter for yyyy-MM-dd'T'HH:mm:ssZZ
      */
     public static DateTimeFormatter dateTimeNoMillis() {
         if (dtx == null) {
@@ -959,10 +979,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter for a full ordinal date and time, using a four
-     * digit year and three digit dayOfYear (yyyy-DDD'T'HH:mm:ss.SSSZ).
+     * digit year and three digit dayOfYear (yyyy-DDD'T'HH:mm:ss.SSSZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for yyyy-DDD'T'HH:mm:ss.SSSZ
+     * @return a formatter for yyyy-DDD'T'HH:mm:ss.SSSZZ
      * @since 1.1
      */
     public static DateTimeFormatter ordinalDateTime() {
@@ -977,10 +997,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter for a full ordinal date and time without millis,
-     * using a four digit year and three digit dayOfYear (yyyy-DDD'T'HH:mm:ssZ).
+     * using a four digit year and three digit dayOfYear (yyyy-DDD'T'HH:mm:ssZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for yyyy-DDD'T'HH:mm:ssZ
+     * @return a formatter for yyyy-DDD'T'HH:mm:ssZZ
      * @since 1.1
      */
     public static DateTimeFormatter ordinalDateTimeNoMillis() {
@@ -1005,10 +1025,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter that combines a full weekyear date and time,
-     * separated by a 'T' (xxxx-'W'ww-e'T'HH:mm:ss.SSSZ).
+     * separated by a 'T' (xxxx-'W'ww-e'T'HH:mm:ss.SSSZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for xxxx-'W'ww-e'T'HH:mm:ss.SSSZ
+     * @return a formatter for xxxx-'W'ww-e'T'HH:mm:ss.SSSZZ
      */
     public static DateTimeFormatter weekDateTime() {
         if (wdt == null) {
@@ -1022,10 +1042,10 @@ public class ISODateTimeFormat {
 
     /**
      * Returns a formatter that combines a full weekyear date and time without millis,
-     * separated by a 'T' (xxxx-'W'ww-e'T'HH:mm:ssZ).
+     * separated by a 'T' (xxxx-'W'ww-e'T'HH:mm:ssZZ).
      * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
      * 
-     * @return a formatter for xxxx-'W'ww-e'T'HH:mm:ssZ
+     * @return a formatter for xxxx-'W'ww-e'T'HH:mm:ssZZ
      */
     public static DateTimeFormatter weekDateTimeNoMillis() {
         if (wdtx == null) {
@@ -1048,8 +1068,8 @@ public class ISODateTimeFormat {
         if (bd == null) {
             bd = new DateTimeFormatterBuilder()
                 .appendYear(4, 4)
-                .appendMonthOfYear(2)
-                .appendDayOfMonth(2)
+                .appendFixedDecimal(DateTimeFieldType.monthOfYear(), 2)
+                .appendFixedDecimal(DateTimeFieldType.dayOfMonth(), 2)
                 .toFormatter();
         }
         return bd;
@@ -1059,18 +1079,18 @@ public class ISODateTimeFormat {
      * Returns a basic formatter for a two digit hour of day, two digit minute
      * of hour, two digit second of minute, three digit millis, and time zone
      * offset (HHmmss.SSSZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for HHmmss.SSSZ
      */
     public static DateTimeFormatter basicTime() {
         if (bt == null) {
             bt = new DateTimeFormatterBuilder()
-                .appendHourOfDay(2)
-                .appendMinuteOfHour(2)
-                .appendSecondOfMinute(2)
+                .appendFixedDecimal(DateTimeFieldType.hourOfDay(), 2)
+                .appendFixedDecimal(DateTimeFieldType.minuteOfHour(), 2)
+                .appendFixedDecimal(DateTimeFieldType.secondOfMinute(), 2)
                 .appendLiteral('.')
-                .appendMillisOfSecond(3)
+                .appendFractionOfSecond(3, 9)
                 .appendTimeZoneOffset("Z", false, 2, 2)
                 .toFormatter();
         }
@@ -1080,16 +1100,16 @@ public class ISODateTimeFormat {
     /**
      * Returns a basic formatter for a two digit hour of day, two digit minute
      * of hour, two digit second of minute, and time zone offset (HHmmssZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for HHmmssZ
      */
     public static DateTimeFormatter basicTimeNoMillis() {
         if (btx == null) {
             btx = new DateTimeFormatterBuilder()
-                .appendHourOfDay(2)
-                .appendMinuteOfHour(2)
-                .appendSecondOfMinute(2)
+                .appendFixedDecimal(DateTimeFieldType.hourOfDay(), 2)
+                .appendFixedDecimal(DateTimeFieldType.minuteOfHour(), 2)
+                .appendFixedDecimal(DateTimeFieldType.secondOfMinute(), 2)
                 .appendTimeZoneOffset("Z", false, 2, 2)
                 .toFormatter();
         }
@@ -1100,7 +1120,7 @@ public class ISODateTimeFormat {
      * Returns a basic formatter for a two digit hour of day, two digit minute
      * of hour, two digit second of minute, three digit millis, and time zone
      * offset prefixed by 'T' ('T'HHmmss.SSSZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for 'T'HHmmss.SSSZ
      */
@@ -1118,7 +1138,7 @@ public class ISODateTimeFormat {
      * Returns a basic formatter for a two digit hour of day, two digit minute
      * of hour, two digit second of minute, and time zone offset prefixed by 'T'
      * ('T'HHmmssZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for 'T'HHmmssZ
      */
@@ -1135,7 +1155,7 @@ public class ISODateTimeFormat {
     /**
      * Returns a basic formatter that combines a basic date and time, separated
      * by a 'T' (yyyyMMdd'T'HHmmss.SSSZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for yyyyMMdd'T'HHmmss.SSSZ
      */
@@ -1152,7 +1172,7 @@ public class ISODateTimeFormat {
     /**
      * Returns a basic formatter that combines a basic date and time without millis,
      * separated by a 'T' (yyyyMMdd'T'HHmmssZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for yyyyMMdd'T'HHmmssZ
      */
@@ -1177,7 +1197,7 @@ public class ISODateTimeFormat {
         if (bod == null) {
             bod = new DateTimeFormatterBuilder()
                 .appendYear(4, 4)
-                .appendDayOfYear(3)
+                .appendFixedDecimal(DateTimeFieldType.dayOfYear(), 3)
                 .toFormatter();
         }
         return bod;
@@ -1186,7 +1206,7 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a full ordinal date and time, using a four
      * digit year and three digit dayOfYear (yyyyDDD'T'HHmmss.SSSZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for yyyyDDD'T'HHmmss.SSSZ
      * @since 1.1
@@ -1204,7 +1224,7 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a full ordinal date and time without millis,
      * using a four digit year and three digit dayOfYear (yyyyDDD'T'HHmmssZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for yyyyDDD'T'HHmmssZ
      * @since 1.1
@@ -1230,8 +1250,8 @@ public class ISODateTimeFormat {
             bwd = new DateTimeFormatterBuilder()
                 .appendWeekyear(4, 4)
                 .appendLiteral('W')
-                .appendWeekOfWeekyear(2)
-                .appendDayOfWeek(1)
+                .appendFixedDecimal(DateTimeFieldType.weekOfWeekyear(), 2)
+                .appendFixedDecimal(DateTimeFieldType.dayOfWeek(), 1)
                 .toFormatter();
         }
         return bwd;
@@ -1240,7 +1260,7 @@ public class ISODateTimeFormat {
     /**
      * Returns a basic formatter that combines a basic weekyear date and time,
      * separated by a 'T' (xxxx'W'wwe'T'HHmmss.SSSZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for xxxx'W'wwe'T'HHmmss.SSSZ
      */
@@ -1257,7 +1277,7 @@ public class ISODateTimeFormat {
     /**
      * Returns a basic formatter that combines a basic weekyear date and time
      * without millis, separated by a 'T' (xxxx'W'wwe'T'HHmmssZ).
-     * The time zone offset is 'Z' for zero, and of the form '\u00b1HH:mm' for non-zero.
+     * The time zone offset is 'Z' for zero, and of the form '\u00b1HHmm' for non-zero.
      * 
      * @return a formatter for xxxx'W'wwe'T'HHmmssZ
      */
@@ -1401,7 +1421,8 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a two digit hour of day, two digit minute of
      * hour, two digit second of minute, and three digit fraction of
-     * second. (HH:mm:ss.SSS)
+     * second (HH:mm:ss.SSS). Parsing will parse up to 3 fractional second
+     * digits.
      * 
      * @return a formatter for HH:mm:ss.SSS
      */
@@ -1411,7 +1432,8 @@ public class ISODateTimeFormat {
                 .append(hourElement())
                 .append(minuteElement())
                 .append(secondElement())
-                .append(millisElement())
+                .appendLiteral('.')
+                .appendFractionOfSecond(3, 3)
                 .toFormatter();
         }
         return hmsl;
@@ -1420,7 +1442,8 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter for a two digit hour of day, two digit minute of
      * hour, two digit second of minute, and three digit fraction of
-     * second. (HH:mm:ss.SSS)
+     * second (HH:mm:ss.SSS). Parsing will parse up to 9 fractional second
+     * digits, throwing away all except the first three.
      * 
      * @return a formatter for HH:mm:ss.SSS
      */
@@ -1491,7 +1514,8 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter that combines a full date, two digit hour of day,
      * two digit minute of hour, two digit second of minute, and three digit
-     * fraction of second. (yyyy-MM-dd'T'HH:mm:ss.SSS)
+     * fraction of second (yyyy-MM-dd'T'HH:mm:ss.SSS). Parsing will parse up
+     * to 3 fractional second digits.
      * 
      * @return a formatter for yyyy-MM-dd'T'HH:mm:ss.SSS
      */
@@ -1509,7 +1533,8 @@ public class ISODateTimeFormat {
     /**
      * Returns a formatter that combines a full date, two digit hour of day,
      * two digit minute of hour, two digit second of minute, and three digit
-     * fraction of second. (yyyy-MM-dd'T'HH:mm:ss.SSS)
+     * fraction of second (yyyy-MM-dd'T'HH:mm:ss.SSS). Parsing will parse up
+     * to 9 fractional second digits, throwing away all except the first three.
      * 
      * @return a formatter for yyyy-MM-dd'T'HH:mm:ss.SSS
      */
@@ -1631,16 +1656,6 @@ public class ISODateTimeFormat {
         return sme;
     }
 
-    private static DateTimeFormatter millisElement() {
-        if (lse == null) {
-            lse = new DateTimeFormatterBuilder()
-                .appendLiteral('.')
-                .appendMillisOfSecond(3)
-                .toFormatter();
-        }
-        return lse;
-    }
-
     private static DateTimeFormatter fractionElement() {
         if (fse == null) {
             fse = new DateTimeFormatterBuilder()
